DJANGO SIDEBAR
==============

Dynamic Sidebar creation for Django. Easily create and manage sidebar from Django Admin.

NOTE
====

I am still preparing for the documentation and how to use it, I put it on PyPi because I need it to use it in my client project.

If you are in rush, and intrested on how to use this app, just mail me a ekaputra[at]balitechy[dot]com.

